;; Generated package description from hiddenquote.el  -*- no-byte-compile: t -*-
(define-package "hiddenquote" "1.1.0.20210210.151753" "Major mode for doing hidden quote puzzles" '((emacs "25.1")) :keywords '("games") :authors '(("Mauro Aranda" . "maurooaranda@gmail.com")) :maintainer '("Mauro Aranda" . "maurooaranda@gmail.com") :url "http://mauroaranda.com/puzzles/hidden-quote-puzzle/")
